[![Coverage Status](https://coveralls.io/repos/github/valentinaschueller/scriptengine-tasks-ecearth/badge.svg?branch=master)](https://coveralls.io/github/valentinaschueller/scriptengine-tasks-ecearth?branch=master)

# ScriptEngine Tasks for EC-Earth

Provides [ScriptEngine](https://github.com/uwefladrich/scriptengine) tasks useful for the EC-Earth climate model.

This package is currently being developed. The documentation can be found in the `docs` folder and will be continuously updated.
